scinumtools.phys.units package
==============================

Submodules
----------

scinumtools.phys.units.BaseUnitsClass module
--------------------------------------------

.. automodule:: scinumtools.phys.units.BaseUnitsClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.DimensionsClass module
---------------------------------------------

.. automodule:: scinumtools.phys.units.DimensionsClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.FractionClass module
-------------------------------------------

.. automodule:: scinumtools.phys.units.FractionClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.QuantityClass module
-------------------------------------------

.. automodule:: scinumtools.phys.units.QuantityClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.UnitClass module
---------------------------------------

.. automodule:: scinumtools.phys.units.UnitClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.UnitConverters module
--------------------------------------------

.. automodule:: scinumtools.phys.units.UnitConverters
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.phys.units.UnitList module
--------------------------------------

.. automodule:: scinumtools.phys.units.UnitList
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.phys.units
   :members:
   :undoc-members:
   :show-inheritance:
